function [x,mn]=nt_demean(x,w)
%[y,mn]=nt_demean(x,w) - remove weighted mean over cols
% 
%  w is optional
%
%  if w is a vector with fewer samples than size(x,1), it is interpreted as
%  a vector of indices to be set to 1, the others being set to 0.  
%
% NoiseTools

if nargin<2; w=[]; end
if nargin<1; error('!');end
nt_greetings;

if iscell(x) % cell
    if isempty(w)
        for k=1:numel(x)
            x{k}=nt_demean(x{k});
        end
    else
        if ~iscell(w)||numel(w)~=numel(x); error('!'); end
        for k=1:numel(x)
            x{k}=nt_demean(x{k},w{k});
        end
    end
    return
end

if isempty(w);
    
    m=size(x,1);
    x=nt_unfold(x);
    mn=mean(double(x),1);
    x=nt_vecadd(x,-mn);
    x=nt_fold(x,m);
    
else
    
    if numel(w)<size(x,1) % interpret w as array of indices to set to 1   !!!! DANGEROUS
        w=w(:);
        if min(w)<1 || max(w)>size(x,1);
            error('w interpreted as indices but values are out of range');
        end
        ww=zeros(size(x,1),1);
        ww(w)=1;
        w=ww;
    end
    
    if size(w,1)~=size(x,1)
        error('X and W should have same nrows'); 
    end
    
    if ndims(x)==3 % check/fix size of w
        if size(w,3)==1 
            w=repmat(w,[1,1,size(x,3)]);
        elseif size(w,3)~=size(x,3)
            error('W should have same npages as X, or else 1');
        end
    end
    
    m=size(x,1);
    x=nt_unfold(x);
    w=nt_unfold(w);
    
    if size(w,2)==size(x,2);
        mn=sum(x.*w) ./ (sum(w,1)+eps);
    elseif size(w,2)==1;
        mn=sum(nt_vecmult(double(x),w),1) ./ (sum(w,1)+eps);
    else
        error('W should have same ncols as X, or else 1');
    end

    x=bsxfun(@minus,x,mn);
    x=nt_fold(x,m);
end

